var searchData=
[
  ['l1_5f1_0',['l1_1',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a364d67b88ba145c54a941527419c615e',1,'Steinberg::FUnknownImpl::UID::l1_1'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a364d67b88ba145c54a941527419c615e',1,'Steinberg::U::UID::l1_1']]],
  ['l1_5f2_1',['l1_2',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a69135c9ccda11551789cc40c2ba383b7',1,'Steinberg::FUnknownImpl::UID::l1_2'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a69135c9ccda11551789cc40c2ba383b7',1,'Steinberg::U::UID::l1_2']]],
  ['l1_5f3_2',['l1_3',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a113168334159478ee29ac1f9ab97590f',1,'Steinberg::FUnknownImpl::UID::l1_3'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a113168334159478ee29ac1f9ab97590f',1,'Steinberg::U::UID::l1_3']]],
  ['l1_5f4_3',['l1_4',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a9f14c775b18f5ac39bb547b0b2b8ab77',1,'Steinberg::FUnknownImpl::UID::l1_4'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a9f14c775b18f5ac39bb547b0b2b8ab77',1,'Steinberg::U::UID::l1_4']]],
  ['l2_5f1_4',['l2_1',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585aabd2f67af8e67b1ff9967ccfdffba753',1,'Steinberg::FUnknownImpl::UID::l2_1'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585aabd2f67af8e67b1ff9967ccfdffba753',1,'Steinberg::U::UID::l2_1']]],
  ['l2_5f2_5',['l2_2',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a84847d1fdfb70e454b3fe7b2ce6d7f1e',1,'Steinberg::FUnknownImpl::UID::l2_2'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a84847d1fdfb70e454b3fe7b2ce6d7f1e',1,'Steinberg::U::UID::l2_2']]],
  ['l2_5f3_6',['l2_3',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585aaaef82e33e7cc9147ac4b596c0f0bdba',1,'Steinberg::FUnknownImpl::UID::l2_3'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585aaaef82e33e7cc9147ac4b596c0f0bdba',1,'Steinberg::U::UID::l2_3']]],
  ['l2_5f4_7',['l2_4',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a74fb2f88033d775fa980d8599ceb8e9e',1,'Steinberg::FUnknownImpl::UID::l2_4'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a74fb2f88033d775fa980d8599ceb8e9e',1,'Steinberg::U::UID::l2_4']]],
  ['l2l_8',['l2l',['../classSteinberg_1_1Vst_1_1mda_1_1ImageProcessor.html#aa5406a33f66b3c9f16d02ba90cbd1767',1,'Steinberg::Vst::mda::ImageProcessor']]],
  ['l2r_9',['l2r',['../classSteinberg_1_1Vst_1_1mda_1_1ImageProcessor.html#a5063ff21a588dae1717397282e1e24e1',1,'Steinberg::Vst::mda::ImageProcessor']]],
  ['l3_5f1_10',['l3_1',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a6fc24ff5fdae1278dc8f6d59bc5aa199',1,'Steinberg::FUnknownImpl::UID::l3_1'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a6fc24ff5fdae1278dc8f6d59bc5aa199',1,'Steinberg::U::UID::l3_1']]],
  ['l3_5f2_11',['l3_2',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585aaf4b2926ae53fed36cc5e9c15af53cf0',1,'Steinberg::FUnknownImpl::UID::l3_2'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585aaf4b2926ae53fed36cc5e9c15af53cf0',1,'Steinberg::U::UID::l3_2']]],
  ['l3_5f3_12',['l3_3',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a933915a7364eee7f4a1afd8c7ce15e1d',1,'Steinberg::FUnknownImpl::UID::l3_3'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a933915a7364eee7f4a1afd8c7ce15e1d',1,'Steinberg::U::UID::l3_3']]],
  ['l3_5f4_13',['l3_4',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a65e1960d794f7fc803c279f1867948e8',1,'Steinberg::FUnknownImpl::UID::l3_4'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a65e1960d794f7fc803c279f1867948e8',1,'Steinberg::U::UID::l3_4']]],
  ['l4_5f1_14',['l4_1',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a8048ed6bbf575acb076473860c596ad7',1,'Steinberg::FUnknownImpl::UID::l4_1'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a8048ed6bbf575acb076473860c596ad7',1,'Steinberg::U::UID::l4_1']]],
  ['l4_5f2_15',['l4_2',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a42262067506945b6c6b7f20499a58283',1,'Steinberg::FUnknownImpl::UID::l4_2'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a42262067506945b6c6b7f20499a58283',1,'Steinberg::U::UID::l4_2']]],
  ['l4_5f3_16',['l4_3',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585afdf8e144b07277b747cd719cd5e90fbb',1,'Steinberg::FUnknownImpl::UID::l4_3'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585afdf8e144b07277b747cd719cd5e90fbb',1,'Steinberg::U::UID::l4_3']]],
  ['l4_5f4_17',['l4_4',['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a7bbddf97f369fb4059a743b4826fafa6',1,'Steinberg::FUnknownImpl::UID::l4_4'],['../../base/structSteinberg_1_1FUnknownImpl_1_1UID.html#ae8424d9713d8cfd8dae09a5826726585a7bbddf97f369fb4059a743b4826fafa6',1,'Steinberg::U::UID::l4_4']]],
  ['large_5fint_18',['LARGE_INT',['../../base/group__smtgtypedef.html#ga9cd1730908299276af7bc0baa8c5197e',1,'Steinberg']]],
  ['lastnote_19',['lastnote',['../classSteinberg_1_1Vst_1_1mda_1_1JX10Processor.html#a1218aeb20cac0f3c0a7ed459b11572c7',1,'Steinberg::Vst::mda::JX10Processor']]],
  ['lastpreset_20',['lastPreset',['../../vstsdk/classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html#a46ad71fcafe9288a61041dd87173d9a6',1,'Steinberg::Vst::InterAppAudio::PresetManager']]],
  ['ldel_21',['ldel',['../classSteinberg_1_1Vst_1_1mda_1_1DelayProcessor.html#ade07a3997e8ab6e7f618f6e07b70853e',1,'Steinberg::Vst::mda::DelayProcessor']]],
  ['ldisp_22',['ldisp',['../classSteinberg_1_1Vst_1_1mda_1_1SplitterProcessor.html#a649395e40d5cf5c283fe43b7581e8690',1,'Steinberg::Vst::mda::SplitterProcessor']]],
  ['left_23',['left',['../../base/structSteinberg_1_1ViewRect.html#ae08ef45a841fb76eef2ed11f7f6661ad',1,'Steinberg::ViewRect::left'],['../classSteinberg_1_1Vst_1_1mda_1_1TestToneProcessor.html#a7d10b0c779bad3aabf067d52035f7052',1,'Steinberg::Vst::mda::TestToneProcessor::left']]],
  ['legacymidiccout_2fsource_2fplug_2ecpp_24',['plug.cpp',['../legacymidiccout_2source_2plug_8cpp.html',1,'']]],
  ['legacymidiccout_2fsource_2fplug_2eh_25',['plug.h',['../legacymidiccout_2source_2plug_8h.html',1,'']]],
  ['legacymidiccout_2fsource_2fplugcids_2eh_26',['plugcids.h',['../legacymidiccout_2source_2plugcids_8h.html',1,'']]],
  ['legacymidiccout_2fsource_2fplugcontroller_2ecpp_27',['plugcontroller.cpp',['../legacymidiccout_2source_2plugcontroller_8cpp.html',1,'']]],
  ['legacymidiccout_2fsource_2fplugcontroller_2eh_28',['plugcontroller.h',['../legacymidiccout_2source_2plugcontroller_8h.html',1,'']]],
  ['legacymidiccout_2fsource_2fplugentry_2ecpp_29',['plugentry.cpp',['../legacymidiccout_2source_2plugentry_8cpp.html',1,'']]],
  ['legacymidiccout_2fsource_2fplugparamids_2eh_30',['plugparamids.h',['../legacymidiccout_2source_2plugparamids_8h.html',1,'']]],
  ['legacymidiccout_2fsource_2fversion_2eh_31',['version.h',['../legacymidiccout_2source_2version_8h.html',1,'']]],
  ['legacymidiccoutevent_32',['LegacyMIDICCOutEvent',['../../vstinterfaces/structSteinberg_1_1Vst_1_1LegacyMIDICCOutEvent.html',1,'Steinberg::Vst']]],
  ['len_33',['len',['../classSteinberg_1_1Vst_1_1mda_1_1TestToneProcessor.html#af67b7bab427a3a151b2b23026e913ef7',1,'Steinberg::Vst::mda::TestToneProcessor']]],
  ['length_34',['length',['../../vstinterfaces/structSteinberg_1_1Vst_1_1NoteOnEvent.html#ab91fc0c68b937719298bf91ba200640c',1,'Steinberg::Vst::NoteOnEvent']]],
  ['lesliecontroller_35',['LeslieController',['../classSteinberg_1_1Vst_1_1mda_1_1LeslieController.html',1,'LeslieController'],['../classSteinberg_1_1Vst_1_1mda_1_1LeslieController.html#a0830a7c4e566bbf4ae18958c6ededbb1',1,'Steinberg::Vst::mda::LeslieController::LeslieController()']]],
  ['leslieprocessor_36',['LeslieProcessor',['../classSteinberg_1_1Vst_1_1mda_1_1LeslieProcessor.html',1,'LeslieProcessor'],['../classSteinberg_1_1Vst_1_1mda_1_1LeslieProcessor.html#a9795cdf660ee0fa4967e49b141d701af',1,'Steinberg::Vst::mda::LeslieProcessor::LeslieProcessor()']]],
  ['lev_37',['lev',['../structSteinberg_1_1Vst_1_1mda_1_1JX10Processor_1_1VOICE.html#a00f6e6f2de2f23ec7703279c5e7c1ad6',1,'Steinberg::Vst::mda::JX10Processor::VOICE']]],
  ['lev2_38',['lev2',['../structSteinberg_1_1Vst_1_1mda_1_1JX10Processor_1_1VOICE.html#ace21ebc7756114e6dd32f8e1fc7ffb60',1,'Steinberg::Vst::mda::JX10Processor::VOICE']]],
  ['level_39',['Level',['../namespaceSteinberg_1_1Vst_1_1mda.html#ad4a12cdd49d69dab3151c2972b5e76a4aa0db49ba470c1c9ae2128c3470339153',1,'Steinberg::Vst::mda']]],
  ['level_40',['level',['../classSteinberg_1_1Vst_1_1mda_1_1ShepardProcessor.html#a450c3ab9b94a4663caad892b7193b547',1,'Steinberg::Vst::mda::ShepardProcessor::level'],['../classSteinberg_1_1Vst_1_1mda_1_1SplitterProcessor.html#a450c3ab9b94a4663caad892b7193b547',1,'Steinberg::Vst::mda::SplitterProcessor::level']]],
  ['levelfromvel_41',['levelFromVel',['../classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Voice.html#a90c2b57fb705c32e75721aca5b78acc4',1,'Steinberg::Vst::NoteExpressionSynth::Voice']]],
  ['lfo_42',['lfo',['../classSteinberg_1_1Vst_1_1mda_1_1JX10Processor.html#ac43c0eb0d896b09449a184f40150149c',1,'Steinberg::Vst::mda::JX10Processor']]],
  ['lfo0_43',['lfo0',['../classSteinberg_1_1Vst_1_1mda_1_1DX10Processor.html#a931e9878dd9dca52cf2a0cb56a59a583',1,'Steinberg::Vst::mda::DX10Processor::lfo0'],['../classSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor.html#a931e9878dd9dca52cf2a0cb56a59a583',1,'Steinberg::Vst::mda::EPianoProcessor::lfo0']]],
  ['lfo1_44',['lfo1',['../classSteinberg_1_1Vst_1_1mda_1_1DX10Processor.html#ae417c51fb7fd95ce5398df450788c77b',1,'Steinberg::Vst::mda::DX10Processor::lfo1'],['../classSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor.html#ae417c51fb7fd95ce5398df450788c77b',1,'Steinberg::Vst::mda::EPianoProcessor::lfo1']]],
  ['lfohz_45',['lfoHz',['../classSteinberg_1_1Vst_1_1mda_1_1JX10Processor.html#aa7e061d9e236093fbc03c66a8b0b1e64',1,'Steinberg::Vst::mda::JX10Processor']]],
  ['lfomode_46',['lfomode',['../classSteinberg_1_1Vst_1_1mda_1_1RezFilterProcessor.html#a3d53638adcff4102b29f5e11347e19d5',1,'Steinberg::Vst::mda::RezFilterProcessor']]],
  ['lhold_47',['Lhold',['../classSteinberg_1_1Vst_1_1mda_1_1SpecMeterProcessor.html#aeef3a04b5f0c542b4b049d15a29b3232',1,'Steinberg::Vst::mda::SpecMeterProcessor']]],
  ['licensecheck_48',['licenseCheck',['../../vstsdk/classVST3_1_1Hosting_1_1FactoryInfo.html#a8f0936359821bafbd5ec36603d6b7874',1,'VST3::Hosting::FactoryInfo']]],
  ['limitercontroller_49',['LimiterController',['../classSteinberg_1_1Vst_1_1mda_1_1LimiterController.html',1,'LimiterController'],['../classSteinberg_1_1Vst_1_1mda_1_1LimiterController.html#ab931f1f45358939f7a6e46f6bbe73f6b',1,'Steinberg::Vst::mda::LimiterController::LimiterController()']]],
  ['limiterprocessor_50',['LimiterProcessor',['../classSteinberg_1_1Vst_1_1mda_1_1LimiterProcessor.html',1,'LimiterProcessor'],['../classSteinberg_1_1Vst_1_1mda_1_1LimiterProcessor.html#a620bc38468213a1a1200556116d00e6b',1,'Steinberg::Vst::mda::LimiterProcessor::LimiterProcessor()']]],
  ['lin_51',['lin',['../classSteinberg_1_1Vst_1_1mda_1_1DegradeProcessor.html#aab1361e504b14f24ab0335ba905eaef1',1,'Steinberg::Vst::mda::DegradeProcessor']]],
  ['lin2_52',['lin2',['../classSteinberg_1_1Vst_1_1mda_1_1DegradeProcessor.html#a2b14e4cce2142c4ff74ceb653cee8c13',1,'Steinberg::Vst::mda::DegradeProcessor']]],
  ['ll_53',['ll',['../classSteinberg_1_1Vst_1_1mda_1_1SplitterProcessor.html#a4b4c1671e848c3debb26cc1fd9c0de77',1,'Steinberg::Vst::mda::SplitterProcessor']]],
  ['llev_54',['llev',['../classSteinberg_1_1Vst_1_1mda_1_1LeslieProcessor.html#ade24b85bbc1d40c8b9dd564baabd809d',1,'Steinberg::Vst::mda::LeslieProcessor']]],
  ['lmin_55',['Lmin',['../classSteinberg_1_1Vst_1_1mda_1_1SpecMeterProcessor.html#a5d5f28315548a7d539bf0266562a7c86',1,'Steinberg::Vst::mda::SpecMeterProcessor']]],
  ['lmin_56',['lmin',['../classSteinberg_1_1Vst_1_1mda_1_1SpecMeterProcessor.html#a66d1a8d9f79b7f3e7378a379fbcf6a0b',1,'Steinberg::Vst::mda::SpecMeterProcessor']]],
  ['lmix_57',['lmix',['../classSteinberg_1_1Vst_1_1mda_1_1DelayProcessor.html#a4cb5678cbeef8c076aedc860368cc4fa',1,'Steinberg::Vst::mda::DelayProcessor::lmix'],['../classSteinberg_1_1Vst_1_1mda_1_1DubDelayProcessor.html#a4cb5678cbeef8c076aedc860368cc4fa',1,'Steinberg::Vst::mda::DubDelayProcessor::lmix']]],
  ['lmod_58',['lmod',['../classSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor.html#a2377c4ea182991ab3c1380c90b0b7894',1,'Steinberg::Vst::mda::EPianoProcessor']]],
  ['lmom_59',['lmom',['../classSteinberg_1_1Vst_1_1mda_1_1LeslieProcessor.html#a65b24ccf522cbce071a5fd3694a15435',1,'Steinberg::Vst::mda::LeslieProcessor']]],
  ['load_60',['load',['../../vstsdk/classVST3_1_1Hosting_1_1Module.html#ad210dec17843e489c4c87cb1d401444c',1,'VST3::Hosting::Module']]],
  ['loadattributes_61',['loadAttributes',['../../base/classSteinberg_1_1IPersistent.html#a34ba5d29ec54b8d49213549ada3d59fe',1,'Steinberg::IPersistent']]],
  ['loadnextpreset_62',['loadNextPreset',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html#a6d707548076cb27d64e04c155ccba7d2',1,'Steinberg::Vst::IInterAppAudioPresetManager::loadNextPreset()'],['../../vstsdk/classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html#a3cabde7a9da60ba41d928d08bc60b374',1,'Steinberg::Vst::InterAppAudio::PresetManager::loadNextPreset()']]],
  ['loadpreset_63',['loadPreset',['../../vstsdk/classSteinberg_1_1Vst_1_1PresetFile.html#a934b8dae5ccc233b79fcc8a25e0c4235',1,'Steinberg::Vst::PresetFile::loadPreset()'],['../../vstsdk/classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html#a499c00d1698d113024242d598d5ace69',1,'Steinberg::Vst::InterAppAudio::PresetManager::loadPreset(bool next)'],['../../vstsdk/classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html#a89d71e499b5dd3bf4c5ed2d75811f1b5',1,'Steinberg::Vst::InterAppAudio::PresetManager::loadPreset(const char *path)']]],
  ['loadpreviouspreset_64',['loadPreviousPreset',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html#a726a6db5c25f476bcb9d0f8bc7f24245',1,'Steinberg::Vst::IInterAppAudioPresetManager::loadPreviousPreset()'],['../../vstsdk/classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html#a03e03c3eacafc1b39524a5ccbab50faf',1,'Steinberg::Vst::InterAppAudio::PresetManager::loadPreviousPreset()']]],
  ['lockblock_65',['lockBlock',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IDataExchangeHandler.html#a364dfe59ecafb51bd6520fa5ce527540',1,'Steinberg::Vst::IDataExchangeHandler']]],
  ['log_5fcontext_66',['LOG_CONTEXT',['../logevents_8h.html#a779b90f0bd4c9d431184500eff9a3a83',1,'logevents.h']]],
  ['log_5fdesc_67',['LOG_DESC',['../logevents_8h.html#a53f9f6500f910d315237711949181611',1,'logevents.h']]],
  ['log_5ferr_68',['LOG_ERR',['../logevents_8h.html#a96fad55b3f5adf08c39e4c877cf185e3',1,'logevents.h']]],
  ['log_5fevent_5flist_69',['LOG_EVENT_LIST',['../logevents_8h.html#a3ff8f70a8e7742a391579647a740b0cc',1,'logevents.h']]],
  ['log_5fid_70',['LOG_ID',['../logevents_8h.html#ad0f48101b43e62a857a56e15651ee234',1,'logevents.h']]],
  ['log_5finfo_71',['LOG_INFO',['../logevents_8h.html#aeb4f36db01bd128c7afeac5889dac311',1,'logevents.h']]],
  ['log_5fsever_72',['LOG_SEVER',['../logevents_8h.html#afc507aa9af80c3191815907e53ecd31c',1,'logevents.h']]],
  ['log_5fwarn_73',['LOG_WARN',['../logevents_8h.html#aea3f57d6dcc5b4ac957e2679e87dde27',1,'logevents.h']]],
  ['logevent_74',['LogEvent',['../structLogEvent.html',1,'LogEvent'],['../structLogEvent.html#a1b7daede73e8c76095075f2332079223',1,'LogEvent::LogEvent()'],['../structLogEvent.html#ab3d227b6db086ec6fc78dc459f083dbe',1,'LogEvent::LogEvent(const LogEvent &amp;other)']]],
  ['logevents_75',['LogEvents',['../classVSTGUI_1_1EventLogDataBrowserSource.html#a8dab41cfdfbe6a966f48e5217c46f94d',1,'VSTGUI::EventLogDataBrowserSource']]],
  ['logevents_2eh_76',['logevents.h',['../logevents_8h.html',1,'']]],
  ['logscale_77',['LogScale',['../classSteinberg_1_1Vst_1_1LogScale.html',1,'LogScale&lt; T &gt;'],['../classSteinberg_1_1Vst_1_1LogScale.html#a7abbd2328f395af191fab07e08d49bb1',1,'Steinberg::Vst::LogScale::LogScale(T srcMin, T srcMax, T destMin, T destMax, T inValue=0.5, T outValue=0.1)'],['../classSteinberg_1_1Vst_1_1LogScale.html#a0e8c44a773e2ad3c68922ea21425b582',1,'Steinberg::Vst::LogScale::LogScale()']]],
  ['logscale_2eh_78',['logscale.h',['../logscale_8h.html',1,'']]],
  ['logscale_3c_20paramvalue_20_3e_79',['LogScale&lt; ParamValue &gt;',['../classSteinberg_1_1Vst_1_1LogScale.html',1,'Steinberg::Vst']]],
  ['logscaleparameter_80',['LogScaleParameter',['../classSteinberg_1_1Vst_1_1LogScaleParameter.html',1,'LogScaleParameter&lt; T &gt;'],['../classSteinberg_1_1Vst_1_1LogScaleParameter.html#adba578cb2eb7bb794dd38d22adcb8396',1,'Steinberg::Vst::LogScaleParameter::LogScaleParameter()']]],
  ['loop_81',['loop',['../structSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor_1_1VOICE.html#a9531807d582fba717657d34fc72584cf',1,'Steinberg::Vst::mda::EPianoProcessor::VOICE::loop'],['../structSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor_1_1KGRP.html#a9531807d582fba717657d34fc72584cf',1,'Steinberg::Vst::mda::EPianoProcessor::KGRP::loop'],['../structSteinberg_1_1Vst_1_1mda_1_1PianoProcessor_1_1VOICE.html#a9531807d582fba717657d34fc72584cf',1,'Steinberg::Vst::mda::PianoProcessor::VOICE::loop'],['../structSteinberg_1_1Vst_1_1mda_1_1PianoProcessor_1_1KGRP.html#a9531807d582fba717657d34fc72584cf',1,'Steinberg::Vst::mda::PianoProcessor::KGRP::loop']]],
  ['loudnesscontroller_82',['LoudnessController',['../classSteinberg_1_1Vst_1_1mda_1_1LoudnessController.html',1,'LoudnessController'],['../classSteinberg_1_1Vst_1_1mda_1_1LoudnessController.html#ab1e069a5e328d16ced977ee0bf131833',1,'Steinberg::Vst::mda::LoudnessController::LoudnessController()']]],
  ['loudnessprocessor_83',['LoudnessProcessor',['../classSteinberg_1_1Vst_1_1mda_1_1LoudnessProcessor.html',1,'LoudnessProcessor'],['../classSteinberg_1_1Vst_1_1mda_1_1LoudnessProcessor.html#afb7834026dca839331366161d17b2ff0',1,'Steinberg::Vst::mda::LoudnessProcessor::LoudnessProcessor()']]],
  ['lower_20range_84',['lower range',['../classSteinberg_1_1Vst_1_1LogScale.html#example2',1,'Example for compressed lower range'],['../classSteinberg_1_1Vst_1_1LogScale.html#example1',1,'Example for stretched lower range']]],
  ['lpc_85',['lpc',['../classSteinberg_1_1Vst_1_1mda_1_1TalkBoxProcessor.html#a21284dd9fa3680cd23a1d3d842a0f090',1,'Steinberg::Vst::mda::TalkBoxProcessor']]],
  ['lpc_5fdurbin_86',['lpc_durbin',['../classSteinberg_1_1Vst_1_1mda_1_1TalkBoxProcessor.html#a8b28ed1028c3d788aa4b28b97b700ba0',1,'Steinberg::Vst::mda::TalkBoxProcessor']]],
  ['lpeak_87',['Lpeak',['../classSteinberg_1_1Vst_1_1mda_1_1SpecMeterProcessor.html#a3d4a9d27772234d72a52a433bfdec2b0',1,'Steinberg::Vst::mda::SpecMeterProcessor']]],
  ['lpeak_88',['lpeak',['../classSteinberg_1_1Vst_1_1mda_1_1SpecMeterProcessor.html#a96bd95c40bf4460dd8ba322344178021',1,'Steinberg::Vst::mda::SpecMeterProcessor']]],
  ['lpf_89',['lpf',['../classSteinberg_1_1Vst_1_1mda_1_1ComboProcessor.html#a4dd7b9c0d5022ea08cfc8a2227246ba4',1,'Steinberg::Vst::mda::ComboProcessor']]],
  ['lphi_90',['lphi',['../classSteinberg_1_1Vst_1_1mda_1_1LeslieProcessor.html#a16c6b83c21dc8f1d712723bac6968670',1,'Steinberg::Vst::mda::LeslieProcessor']]],
  ['lpp_91',['lpp',['../classSteinberg_1_1Vst_1_1mda_1_1SpecMeterProcessor.html#ab4f5d4adffa695b6f35136bc23b5aefb',1,'Steinberg::Vst::mda::SpecMeterProcessor']]],
  ['lrms_92',['Lrms',['../classSteinberg_1_1Vst_1_1mda_1_1SpecMeterProcessor.html#af6ae703073e9fce0ca9eef23b07232c0',1,'Steinberg::Vst::mda::SpecMeterProcessor']]],
  ['lrms_93',['lrms',['../classSteinberg_1_1Vst_1_1mda_1_1SpecMeterProcessor.html#a3070d8c67fde5aa7e1ed30783734d4da',1,'Steinberg::Vst::mda::SpecMeterProcessor']]],
  ['lset_94',['lset',['../classSteinberg_1_1Vst_1_1mda_1_1LeslieProcessor.html#a11784160b1e993a66a2166bfc11a4359',1,'Steinberg::Vst::mda::LeslieProcessor']]],
  ['lspd_95',['lspd',['../classSteinberg_1_1Vst_1_1mda_1_1LeslieProcessor.html#a73c29127c0e6c2b5a66a809e524174a0',1,'Steinberg::Vst::mda::LeslieProcessor']]],
  ['lthr_96',['lthr',['../classSteinberg_1_1Vst_1_1mda_1_1DynamicsProcessor.html#a50e9975569ed80dfccbda8f163d0b15b',1,'Steinberg::Vst::mda::DynamicsProcessor']]],
  ['lwid_97',['lwid',['../classSteinberg_1_1Vst_1_1mda_1_1LeslieProcessor.html#a8c54deb8bdb793602cb816113bcd2c7c',1,'Steinberg::Vst::mda::LeslieProcessor']]]
];
